@@ -10,7 +10,7 @@ use Mojolicious::Plugin::DataTables::SSP::Column;
 use Mojolicious::Plugin::DataTables::SSP::Params;
 use Mojolicious::Plugin::DataTables::SSP::Results;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 sub register {
 
@@ -55,11 +55,17 @@ sub _dt_ssp {
     my $db      = delete $args{db};
     my @columns = delete $args{columns};
     my $debug   = delete $args{debug};
+    my $where   = delete $args{where};
 
-    my $regexp_operator = 'REGEXP';    # MySQL and SQLite use REGEXP operator
+    if ( !$db ) {
+        $c->app->log->error('Missing "db" param') if ($debug);
+        return {};
+    }
+
+    my $regexp_operator = 'REGEXP';    # REGEXP operator for MySQL and SQLite
     my $db_type         = ref $db;
 
-    # PostgreSQL use "~" operator
+    # "~" operator for PostgreSQL
     if ( $db_type =~ /Mojo::Pg/ ) {
         $regexp_operator = '~';
     }
@@ -76,6 +82,10 @@ sub _dt_ssp {
 
     push @db_columns, @columns;
 
+    if ($where) {
+        push @db_filters, $where;
+    }
+
     # Column filter
     my @col_filters;
 
@@ -94,7 +104,7 @@ sub _dt_ssp {
     }
 
     if (@col_filters) {
-        push @db_filters, '(' . join( ' OR ', @col_filters ) . ')';
+        push @db_filters, '(' . join( ' AND ', @col_filters ) . ')';
     }
 
     # Global Search
@@ -229,6 +239,7 @@ sub _decode_params {
     $dt_params->{timestamp} = $req_params->param('_')      || 0;
     $dt_params->{columns}   = [];
     $dt_params->{order}     = [];
+    $dt_params->{where}     = undef;
 
     foreach ( @{ $req_params->names } ) {
 
@@ -298,6 +309,7 @@ Mojolicious::Plugin::DataTables - DataTables Plugin for Mojolicious
         db      => $db,
         columns => qw/role create_date/,
         debug   => 1,
+        where   => 'status = "active"'
         options => [
             {
                 label     => 'UID',
@@ -354,6 +366,8 @@ Params:
 
 =item C<debug>: Write debug information using L<Mojo::Log> class
 
+=item C<where>: WHERE condition in SQL format
+
 =item C<options>: Array of options (see below)
 
 =back
